#cython: language_level=3

from .capidmscolumn cimport *
from obitools3.obidms.obidmscolumn.obidmscolumn_int.capidmscolumn_int import OBIDMS_column_int
from obitools3.obidms.obidmscolumn.obidmscolumn_float.capidmscolumn_float import OBIDMS_column_float
from obitools3.obidms.obidmscolumn.obidmscolumn_bool.capidmscolumn_bool import OBIDMS_column_bool
from obitools3.obidms.obidmscolumn.obidmscolumn_char.capidmscolumn_char import OBIDMS_column_char
from obitools3.obidms.obidmscolumn.obidmscolumn_idx.capidmscolumn_idx import OBIDMS_column_idx


cdef class OBIDMS_column:

    #Should only be initialized through a subclass (or open())
    def __init__(self, dms_name, column_name, 
                 create, clone, clone_data,
                 version_number, type,
                 nb_elements, nb_elements_per_line, 
                 elements_names):
        column_name_b = column_name.encode(encoding='UTF-8')
        dms_name_b = dms_name.encode(encoding='UTF-8')
        self.dms_name = dms_name
        self.column_name = column_name
        self.data_type = (name_data_type(type)).decode('UTF-8')
        if create :
            dms = obi_dms(dms_name_b)
            self.dms = dms
            if elements_names == None :  
                elements_names_b = column_name_b
            else :
                elements_names_b = elements_names.encode(encoding='UTF-8')
            self.pointer = obi_create_column(self.dms, column_name_b, type, nb_elements, nb_elements_per_line, elements_names_b)
        else :
            dms = obi_open_dms(dms_name_b)
            self.dms = dms
            if clone :
                self.pointer = obi_clone_column(self.dms, column_name_b, version_number, clone_data)
            else :
                self.pointer = obi_open_column(self.dms, column_name_b, version_number)
    
    def __iter__(self):
        elements_names = self.get_elements_names()
        if len(elements_names) > 1 :
            multiple_elements = True
        else :
            element_name = elements_names[0]
        line_count = obi_column_get_line_count(self.pointer)
        for line_nb in xrange(line_count):
            if multiple_elements :
                line = []
                for element_name in elements_names :
                    line.append(self.get_item(line_nb, element_name))
            else :
                line = self.get_item(line_nb, element_name)
            yield line

    def __setitem__(self, line_nb, value):
        self.set_item(line_nb, "", value)
        
    def __getitem__(self, line_nb):
        return self.get_item(line_nb, "")
    
    def get_elements_names(self):
        elements_names = obi_column_get_elements_names(self.pointer)
        return (elements_names.decode('UTF-8')).split(';')
         
    def get_element_index_from_name(self, element_name):
        element_name = element_name.encode(encoding='UTF-8')
        return obi_column_get_element_index_from_name(self.pointer, element_name)
    
    def get_data_type(self):
        return self.data_type
    
#    def __del__(self):
#        if obi_close_column(self.pointer) != 0 :
#            raise Exception("Problem closing a column")
    
    @staticmethod
    def open(dms_name, column_name, 
             create=False, clone=False, clone_data=True,
             version_number=-1, type=None, 
             nb_elements=None, nb_elements_per_line=1, 
             elements_names=None):
        
        column_name_b = column_name.encode(encoding='UTF-8')
        dms_name_b = dms_name.encode(encoding='UTF-8')
        dms = obi_dms(dms_name_b)
        
        if type is None :
            if create :
                print("A data type must be specified")
            else :
                type = obi_column_get_data_type_from_name(dms, column_name_b)

        if type == 1 :
            column = OBIDMS_column_int(dms_name, column_name, 
                                       create, clone, clone_data, 
                                       version_number, type, 
                                       nb_elements, nb_elements_per_line, 
                                       elements_names)
        
        elif type == 2 :
            column = OBIDMS_column_float(dms_name, column_name, 
                                       create, clone, clone_data, 
                                       version_number, type, 
                                       nb_elements, nb_elements_per_line, 
                                       elements_names)

        elif type == 3 :
            column = OBIDMS_column_bool(dms_name, column_name, 
                                       create, clone, clone_data, 
                                       version_number, type, 
                                       nb_elements, nb_elements_per_line, 
                                       elements_names)

        elif type == 4 :
            column = OBIDMS_column_char(dms_name, column_name, 
                                       create, clone, clone_data, 
                                       version_number, type, 
                                       nb_elements, nb_elements_per_line, 
                                       elements_names)

        elif type == 5 :
            column = OBIDMS_column_idx(dms_name, column_name, 
                                       create, clone, clone_data, 
                                       version_number, type, 
                                       nb_elements, nb_elements_per_line, 
                                       elements_names)
        
        else :
            "Problem with the data type"
            
        return column
   
        
        
        