/****************************************************************************
 * OBIDMS_column_bool header file                                            *
 ****************************************************************************/

/**
 * @file obidsmcolumn_bool.h
 * @author Celine Mercier
 * @date August 10th 2015
 * @brief Header file for the functions handling OBIColumns containing data with the OBIType OBI_BOOL.
 */


#include <stdlib.h>
#include <stdio.h>

#include "obidmscolumn.h"
#include "obitypes.h"


/**
 * @brief Sets a value in an OBIDMS column containing data with the type OBI_BOOL.
 *
 * @param column a pointer as returned by obi_create_column()
 * @warning Pointers returned by obi_open_column() don't allow writing.
 *
 * @param line_nb the number of the line where the value should be set
 *
 * @param element_idx the index of the element that should be set in the line
 *
 * @param value the value that should be set
 *
 * @return an integer value indicating the success of the operation.
 *
 * @retvalue 0 on success
 * @retvalue -1 on failure and the `obi_errno` variable is set.
 *
 * @since August 2015
 * @author Celine Mercier (celine.mercier@metabarcoding.org)
 */
int obi_column_set_bool(OBIDMS_column_p column, size_t line_nb, size_t element_idx, obibool_t value);


/**
 * @brief Recovers a value in an OBIDMS column containing data with the type OBI_BOOL.
 *
 * @param column a pointer as returned by obi_create_column()
 *
 * @param line_nb the number of the line where the value should be recovered
 *
 * @param element_idx the index of the element that should be recovered in the line
 *
 * @return the recovered value
 *
 * @since August 2015
 * @author Celine Mercier (celine.mercier@metabarcoding.org)
 */
obibool_t obi_column_get_bool(OBIDMS_column_p column, size_t line_nb, size_t element_idx);


